@@ -31,9 +31,9 @@
 # POSSIBILITY OF SUCH DAMAGE.
 
 import os
-import sys
-import unittest
+
 import mock
+from mock import patch
 
 
 class TrueOs():
@@ -72,7 +72,7 @@ class FalseOs(object):
 def test__read_stdout():
     from rospkg.os_detect import _read_stdout
     assert 'hello' == _read_stdout(['echo', 'hello'])
-    assert None == _read_stdout(['bad-command-input-for-rospkg-os-detect'])
+    assert _read_stdout(['bad-command-input-for-rospkg-os-detect']) is None
 
 
 def test_tripwire_ubuntu():
@@ -153,8 +153,6 @@ def test_tripwire_osx():
     os_detect = OsDetect()
     os_detect.get_detector('osx')
 
-from mock import patch
-
 
 def test_osx():
     from rospkg.os_detect import OSX, _osx_codename, OsNotDetected
@@ -237,6 +235,41 @@ def test_arch():
     test()
 
 
+def test_tripwire_manjaro():
+    from rospkg.os_detect import OsDetect
+    os_detect = OsDetect()
+    os_detect.get_detector('manjaro')
+
+
+def test_manjaro():
+    from rospkg.os_detect import Manjaro, OsNotDetected
+    test_dir = os.path.join(get_test_dir(), 'manjaro')
+    detect = Manjaro(os.path.join(test_dir, "manjaro-release"))
+    assert detect.is_os()
+    assert detect.get_version() == ''
+
+    detect = Manjaro()
+    if not detect.is_os():
+        try:
+            detect.get_version()
+            assert False
+        except OsNotDetected:
+            pass
+        try:
+            detect.get_codename()
+            assert False
+        except OsNotDetected:
+            pass
+
+    @patch.object(Manjaro, 'is_os')
+    def test(mock):
+        mock.is_os.return_value = True
+        detect = Manjaro()
+        assert detect.get_version() == ''
+        assert detect.get_codename() == ''
+    test()
+
+
 def test_tripwire_opensuse():
     from rospkg.os_detect import OsDetect
     os_detect = OsDetect()
@@ -336,10 +369,10 @@ def test_fedora():
 
 def test_read_issue():
     from rospkg.os_detect import read_issue
-    assert read_issue('/fake/file') == None
+    assert read_issue('/fake/file') is None
     test_dir = os.path.join(get_test_dir(), 'rhel')
     assert read_issue(os.path.join(test_dir, 'issue')) == \
-    ['Red', 'Hat', 'Enterprise', 'Linux', 'AS', 'release', '3', '(Taroon)']
+        ['Red', 'Hat', 'Enterprise', 'Linux', 'AS', 'release', '3', '(Taroon)']
 
 
 def test_OsDetector():
@@ -365,7 +398,7 @@ def test_OsDetector():
 def test_tripwire_uname_get_machine():
     from rospkg.os_detect import uname_get_machine
     retval = uname_get_machine()
-    assert retval in [None, 'armv7l', 'i386', 'i686', 'ppc', 'ppc64', 'x86_64']
+    assert retval in [None, 'aarch64', 'armv7l', 'i386', 'i686', 'ppc', 'ppc64', 'ppc64le', 's390', 's390x', 'x86_64']
 
 
 def test_tripwire_rhel():
@@ -409,6 +442,35 @@ def test_redhat():
             pass
 
 
+def test_tripwire_slackware():
+    from rospkg.os_detect import OsDetect
+    os_detect = OsDetect()
+    os_detect.get_detector('slackware')
+
+
+def test_slackware():
+    from rospkg.os_detect import Slackware, OsNotDetected
+    test_dir = os.path.join(get_test_dir(), 'slackware')
+    detect = Slackware(os.path.join(test_dir, "slackware-version"))
+    assert detect.is_os()
+    assert detect.get_version() == '14.2'
+    assert detect.get_codename() == ''
+
+    # test freely
+    detect = Slackware()
+    if not detect.is_os():
+        try:
+            detect.get_version()
+            assert False
+        except OsNotDetected:
+            pass
+        try:
+            detect.get_codename()
+            assert False
+        except OsNotDetected:
+            pass
+
+
 def test_tripwire_freebsd():
     from rospkg.os_detect import OsDetect
     os_detect = OsDetect()
@@ -417,7 +479,7 @@ def test_tripwire_freebsd():
 
 def test_freebsd():
     from rospkg.os_detect import FreeBSD, OsNotDetected
-    #TODO
+    # TODO
     if 0:
         test_dir = os.path.join(get_test_dir(), 'freebsd')
         release_file, issue_file = [os.path.join(test_dir, x) for
@@ -459,7 +521,7 @@ def test_freebsd():
 
 def test_cygwin():
     from rospkg.os_detect import Cygwin, OsNotDetected
-    #TODO
+    # TODO
     detect = Cygwin()
     if not detect.is_os():
         try:
@@ -606,7 +668,7 @@ def xTrueOsDetect_second_of_many():
 
 
 def xTrueOsDetect_last_of_many():
-    osa = roslib.os_detect.OSDetect([FalseOs(), FalseOs(), FalseOs(), FalseOs(), TrueOs(),])
+    osa = roslib.os_detect.OSDetect([FalseOs(), FalseOs(), FalseOs(), FalseOs(), TrueOs()])
     assert "os_name", osa.get_name()
     assert "os_version", osa.get_version()
     os_class = osa.get_os()
